﻿using Syncfusion.UI.Xaml.Grid;
using Syncfusion.UI.Xaml.Grid.Cells;
using Syncfusion.UI.Xaml.ScrollAxis;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Runtime.InteropServices.WindowsRuntime;
using System.Text.RegularExpressions;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.System;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Documents;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=402352&clcid=0x409

namespace SfDataGridDemo
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
            this.sfGrid.CellRenderers.Remove("Hyperlink");
            this.sfGrid.CellRenderers.Add("Hyperlink", new CustomCellRendererExt());
                
        }

     
    }

    public class CustomCellRendererExt : GridCellHyperlinkRenderer
    {
        public override bool CanUpdateBinding(GridColumn column)
        {
            return true;
        }

        public override void OnUpdateEditBinding(DataColumnBase dataColumn, HyperlinkButton element, object dataContext)
        {
            var textblock = element.Content as TextBlock;
            if (textblock == null || textblock.Inlines.Count == 0)
                return;

            var underline = textblock.Inlines[0] as Underline;
            var run = underline.Inlines[0] as Run;
            
            var displayval = this.DataGrid.View.GetPropertyAccessProvider().GetFormattedValue(dataContext, dataColumn.GridColumn.MappingName);
            run.Text = displayval == null ? string.Empty : displayval.ToString();
            base.OnUpdateEditBinding(dataColumn, element, dataContext);
        }

        public override void OnInitializeEditElement(DataColumnBase dataColumn, HyperlinkButton uiElement, object dataContext)
        {
            base.OnInitializeEditElement(dataColumn, uiElement, dataContext);
            var column = dataColumn.GridColumn;
            uiElement.SetValue(FrameworkElement.MarginProperty, column.Padding);
            uiElement.SetValue(Control.PaddingProperty, column.Padding);
            uiElement.SetValue(Control.VerticalAlignmentProperty, column.VerticalAlignment);
            var hyperLinkColumn = (GridHyperlinkColumn)column;

            var textBlock = new TextBlock();
            uiElement.Content = textBlock;
            //textBlock.SetBinding(TextBlock.TextProperty, column.ValueBinding);
            if (hyperLinkColumn == null)
                return;

            var underline = new Underline();
            var run = new Run();
            var displayval = this.DataGrid.View.GetPropertyAccessProvider().GetFormattedValue(dataContext, dataColumn.GridColumn.MappingName);
            run.Text = displayval == null ? string.Empty : displayval.ToString();
            underline.Inlines.Add(run);
            textBlock.Inlines.Add(underline);
            textBlock.Style = null;
            
            textBlock.SetValue(TextBlock.TextWrappingProperty, hyperLinkColumn.TextWrapping);
            uiElement.SetValue(TextBlock.TextWrappingProperty, hyperLinkColumn.TextWrapping);
            uiElement.SetValue(Control.HorizontalAlignmentProperty, hyperLinkColumn.HorizontalAlignment);
        }

        protected async override void SetFocus(FrameworkElement uiElement, bool needToFocus)
        {
            base.SetFocus(uiElement, needToFocus);

            var hyperlinkControl = (HyperlinkButton)uiElement;

            hyperlinkControl.FontStretch = Windows.UI.Text.FontStretch.UltraExpanded;
            GridCell gridcell = null;

            if (hyperlinkControl.Parent is GridCell)
                gridcell = hyperlinkControl.Parent as GridCell;

            var navigateText = string.Empty;
            var rowColumnIndex = RowColumnIndex.Empty;
            rowColumnIndex.RowIndex = gridcell != null ? gridcell.ColumnBase.RowIndex : new RowColumnIndex().RowIndex;

            rowColumnIndex.ColumnIndex = gridcell != null ? gridcell.ColumnBase.ColumnIndex : new RowColumnIndex().ColumnIndex;

            if (rowColumnIndex != null && !rowColumnIndex.IsEmpty)
            {
                //Get the column from rowColumnIndex.
                var column = this.DataGrid.Columns[this.DataGrid.ResolveToGridVisibleColumnIndex(rowColumnIndex.ColumnIndex)];


                var recordIndex = this.DataGrid.ResolveToRecordIndex(rowColumnIndex.RowIndex);
                if (recordIndex < 0)
                    return;
                var record1 = this.DataGrid.View.Records.GetItemAt(recordIndex);
                navigateText = record1.GetType().GetProperty(column.MappingName).GetValue(record1).ToString();
               
            }
            
            const string pattern = @"((http|https?|ftp|gopher|telnet|file|notes|ms-help):((//)|(\\\\))+[\w\d:#@%/;$()~_?\+-=\\\.&]*)";

            if (navigateText != null)
            {
                var NavigateUri = Regex.IsMatch("http://www.Syncfusion.com", pattern)
                                  ? new Uri("http://www.Syncfusion.com")
                                  : null;
                if (NavigateUri == null)
                    return;

                hyperlinkControl.NavigateUri = NavigateUri;

                await Launcher.LaunchUriAsync(new Uri(hyperlinkControl.NavigateUri.AbsoluteUri));
            }
        }
     }
}
                                            